==> nhc98_1.16.orig.tar.gz: nhc98-1.16/src/prelude/BinArray/GetUBAEnd.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+8)
#define CT_v194	((void*)startLabel+32)
#define F0_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+40)
#define FN_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+68)
#define CT_v198	((void*)startLabel+120)
#define CF_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+128)
#define CT_v205	((void*)startLabel+296)
#define FN_LAMBDA190	((void*)startLabel+348)
#define CT_v209	((void*)startLabel+400)
#define F0_LAMBDA190	((void*)startLabel+408)
#define ST_v200	((void*)startLabel+432)
#define PP_LAMBDA190	((void*)startLabel+455)
#define PC_LAMBDA190	((void*)startLabel+455)
#define ST_v207	((void*)startLabel+455)
#define PP_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+484)
#define PC_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+484)
#define ST_v196	((void*)startLabel+484)
#define PP_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+510)
#define PC_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+510)
#define ST_v193	((void*)startLabel+510)
#define PS_v197	((void*)startLabel+540)
#define PS_v195	((void*)startLabel+552)
#define PS_v202	((void*)startLabel+564)
#define PS_v201	((void*)startLabel+576)
#define PS_v199	((void*)startLabel+588)
#define PS_v204	((void*)startLabel+600)
#define PS_v203	((void*)startLabel+612)
#define PS_v192	((void*)startLabel+624)
#define PS_v208	((void*)startLabel+636)
#define PS_v206	((void*)startLabel+648)
void FR_NHC_46BinArray_46hs_95getUBAEnd_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95apply1[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PM_NHC_46BinArray[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46BinArray[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v194)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100022
, useLabel(ST_v193)
,	/* CT_v194: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd_35),1)
, useLabel(PS_v192)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v198)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v197)
, 0
, 0
, 0
, 0
, 100022
, useLabel(ST_v196)
,	/* CT_v198: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, useLabel(PS_v195)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v205)
,};
Node FN_NHC_46BinArray_46getUBAEnd[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,HEAP_ARG,1,HEAP_CVAL_P1)
, bytes2word(9,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(10,HEAP_CVAL_N1,22,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,17)
, bytes2word(HEAP_OFF_N1,11,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, useLabel(PS_v204)
, 0
, 0
, 0
, 0
, useLabel(PS_v203)
, 0
, 0
, 0
, 0
, useLabel(PS_v202)
, 0
, 0
, 0
, 0
, useLabel(PS_v201)
, 0
, 0
, 0
, 0
, 130001
, useLabel(ST_v200)
,	/* CT_v205: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAEnd[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAEnd),1)
, useLabel(PS_v199)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA190),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v209)
,	/* FN_LAMBDA190: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v208)
, 0
, 0
, 0
, 0
, 140014
, useLabel(ST_v207)
,	/* CT_v209: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA190: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA190),1)
, useLabel(PS_v206)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_NHC_46BinArray_46getUBAEnd[] = {
 };
Node PC_NHC_46BinArray_46getUBAEnd[] = {
 	/* ST_v200: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,69)
,	/* PP_LAMBDA190: (byte 3) */
 	/* PC_LAMBDA190: (byte 3) */
 	/* ST_v207: (byte 3) */
  bytes2word(110,100,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
, bytes2word(100,58,49,52)
,	/* PP_NHC_46BinArray_46hs_95getUBAEnd: (byte 4) */
 	/* PC_NHC_46BinArray_46hs_95getUBAEnd: (byte 4) */
 	/* ST_v196: (byte 4) */
  bytes2word(58,49,52,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
,	/* PP_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 2) */
 	/* PC_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 2) */
 	/* ST_v193: (byte 2) */
  bytes2word(100,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,104)
, bytes2word(115,95,103,101)
, bytes2word(116,85,66,65)
, bytes2word(69,110,100,35)
, bytes2word(0,0,0,0)
,	/* PS_v197: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAEnd)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v195: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAEnd)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAEnd)
,	/* PS_v202: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_NHC_46Internal_46_95apply1)
,	/* PS_v201: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAEnd)
,	/* PS_v199: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_NHC_46BinArray_46getUBAEnd)
,	/* PS_v204: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v203: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_LAMBDA190)
,	/* PS_v192: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAEnd_35)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAEnd_35)
,	/* PS_v208: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA190)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v206: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA190)
, useLabel(PC_LAMBDA190)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAEnd" NHC.BinArray.hs_getUBAEnd# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAEnd(void*);
#ifdef PROFILE
static SInfo pf_hs_getUBAEnd = {"NHC.BinArray","NHC.BinArray.hs_getUBAEnd#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAEnd_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAEnd(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_hs_getUBAEnd);
  C_RETURN(nodeptr);
}

==> nhc98_1.18.orig.tar.gz: nhc98-1.18/src/prelude/BinArray/GetUBAEnd.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define FN_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+8)
#define CT_v198	((void*)startLabel+32)
#define F0_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+40)
#define FN_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+68)
#define CT_v202	((void*)startLabel+120)
#define CF_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+128)
#define CT_v209	((void*)startLabel+296)
#define FN_LAMBDA194	((void*)startLabel+348)
#define CT_v213	((void*)startLabel+400)
#define F0_LAMBDA194	((void*)startLabel+408)
#define ST_v204	((void*)startLabel+432)
#define PP_LAMBDA194	((void*)startLabel+455)
#define PC_LAMBDA194	((void*)startLabel+455)
#define ST_v211	((void*)startLabel+455)
#define PP_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+490)
#define PC_NHC_46BinArray_46hs_95getUBAEnd	((void*)startLabel+490)
#define ST_v200	((void*)startLabel+490)
#define PP_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+516)
#define PC_NHC_46BinArray_46hs_95getUBAEnd_35	((void*)startLabel+516)
#define ST_v197	((void*)startLabel+516)
#define PS_v201	((void*)startLabel+544)
#define PS_v199	((void*)startLabel+556)
#define PS_v206	((void*)startLabel+568)
#define PS_v205	((void*)startLabel+580)
#define PS_v203	((void*)startLabel+592)
#define PS_v208	((void*)startLabel+604)
#define PS_v207	((void*)startLabel+616)
#define PS_v196	((void*)startLabel+628)
#define PS_v212	((void*)startLabel+640)
#define PS_v210	((void*)startLabel+652)
void FR_NHC_46BinArray_46hs_95getUBAEnd_35(void);
extern Node FN_NHC_46Internal_46_95mkIOok1[];
extern Node FN_NHC_46Internal_46_95apply1[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node FN_Prelude_46Monad_46NHC_46Internal_46IO_46return[];
extern Node PM_NHC_46BinArray[];
extern Node PC_NHC_46Internal_46_95mkIOok1[];
extern Node PC_NHC_46Internal_46_95apply1[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61[];
extern Node PC_Prelude_46Monad_46NHC_46Internal_46IO_46return[];

static Node startLabel[] = {
  bytes2word(1,0,0,1)
, useLabel(CT_v198)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  bytes2word(PUSH_ARG_I1,EVAL,POP_I1,PRIMITIVE)
, useLabel(FR_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(RETURN_EVAL,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, 100001
, useLabel(ST_v197)
,	/* CT_v198: (byte 0) */
  HW(0,1)
, 0
,	/* F0_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 0) */
  CAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd_35),1)
, useLabel(PS_v196)
, 0
, 0
, 0
, bytes2word(0,0,0,0)
, useLabel(CT_v202)
,	/* FN_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_CVAL_P1,8,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v201)
, 0
, 0
, 0
, 0
, 100001
, useLabel(ST_v200)
,	/* CT_v202: (byte 0) */
  HW(2,0)
, 0
,	/* CF_NHC_46BinArray_46hs_95getUBAEnd: (byte 0) */
  VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, useLabel(PS_v199)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46Internal_46_95mkIOok1))
, useLabel(F0_NHC_46BinArray_46hs_95getUBAEnd_35)
, bytes2word(1,0,0,1)
, useLabel(CT_v209)
,};
Node FN_NHC_46BinArray_46getUBAEnd[] = {
  bytes2word(NEEDHEAP_I32,HEAP_CVAL_P1,7,HEAP_CVAL_N1)
, bytes2word(7,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_CVAL_P1,8,HEAP_CVAL_N1,12)
, bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1)
, bytes2word(10,HEAP_ARG,1,HEAP_CVAL_P1)
, bytes2word(9,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(10,HEAP_CVAL_N1,22,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_OFF_N1,17)
, bytes2word(HEAP_OFF_N1,11,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, useLabel(PS_v208)
, 0
, 0
, 0
, 0
, useLabel(PS_v207)
, 0
, 0
, 0
, 0
, useLabel(PS_v206)
, 0
, 0
, 0
, 0
, useLabel(PS_v205)
, 0
, 0
, 0
, 0
, 130001
, useLabel(ST_v204)
,	/* CT_v209: (byte 0) */
  HW(4,1)
, 0
,};
Node F0_NHC_46BinArray_46getUBAEnd[] = {
  CAPTAG(useLabel(FN_NHC_46BinArray_46getUBAEnd),1)
, useLabel(PS_v203)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_NHC_46BinArray_46hs_95getUBAEnd))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95apply1))
, CAPTAG(useLabel(FN_LAMBDA194),1)
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61))
, bytes2word(1,0,0,1)
, useLabel(CT_v213)
,	/* FN_LAMBDA194: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_HEAP,HEAP_CVAL_P1,7)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CREATE,HEAP_SPACE)
, bytes2word(HEAP_SPACE,HEAP_ARG,1,RETURN_EVAL)
, bytes2word(ENDCODE,0,0,0)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v212)
, 0
, 0
, 0
, 0
, 140014
, useLabel(ST_v211)
,	/* CT_v213: (byte 0) */
  HW(1,1)
, 0
,	/* F0_LAMBDA194: (byte 0) */
  CAPTAG(useLabel(FN_LAMBDA194),1)
, useLabel(PS_v210)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46Monad_46NHC_46Internal_46IO_46return))
,};
Node PP_NHC_46BinArray_46getUBAEnd[] = {
 };
Node PC_NHC_46BinArray_46getUBAEnd[] = {
 	/* ST_v204: (byte 0) */
  bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,103,101,116)
, bytes2word(85,66,65,69)
,	/* PP_LAMBDA194: (byte 3) */
 	/* PC_LAMBDA194: (byte 3) */
 	/* ST_v211: (byte 3) */
  bytes2word(110,100,0,78)
, bytes2word(72,67,46,66)
, bytes2word(105,110,65,114)
, bytes2word(114,97,121,46)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
, bytes2word(100,58,49,52)
, bytes2word(58,49,52,45)
, bytes2word(49,52,58,50)
,	/* PP_NHC_46BinArray_46hs_95getUBAEnd: (byte 2) */
 	/* PC_NHC_46BinArray_46hs_95getUBAEnd: (byte 2) */
 	/* ST_v200: (byte 2) */
  bytes2word(57,0,78,72)
, bytes2word(67,46,66,105)
, bytes2word(110,65,114,114)
, bytes2word(97,121,46,104)
, bytes2word(115,95,103,101)
, bytes2word(116,85,66,65)
,	/* PP_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 4) */
 	/* PC_NHC_46BinArray_46hs_95getUBAEnd_35: (byte 4) */
 	/* ST_v197: (byte 4) */
  bytes2word(69,110,100,0)
, bytes2word(78,72,67,46)
, bytes2word(66,105,110,65)
, bytes2word(114,114,97,121)
, bytes2word(46,104,115,95)
, bytes2word(103,101,116,85)
, bytes2word(66,65,69,110)
, bytes2word(100,35,0,0)
,	/* PS_v201: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAEnd)
, useLabel(PC_NHC_46Internal_46_95mkIOok1)
,	/* PS_v199: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAEnd)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAEnd)
,	/* PS_v206: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_NHC_46Internal_46_95apply1)
,	/* PS_v205: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAEnd)
,	/* PS_v203: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_NHC_46BinArray_46getUBAEnd)
,	/* PS_v208: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46_62_62_61)
,	/* PS_v207: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46getUBAEnd)
, useLabel(PC_LAMBDA194)
,	/* PS_v196: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_NHC_46BinArray_46hs_95getUBAEnd_35)
, useLabel(PC_NHC_46BinArray_46hs_95getUBAEnd_35)
,	/* PS_v212: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA194)
, useLabel(PC_Prelude_46Monad_46NHC_46Internal_46IO_46return)
,	/* PS_v210: (byte 0) */
  useLabel(PM_NHC_46BinArray)
, useLabel(PP_LAMBDA194)
, useLabel(PC_LAMBDA194)
,};

#include <haskell2c.h>
#include <HsFFI.h>

/* foreign import ccall "hs_getUBAEnd" NHC.BinArray.hs_getUBAEnd# 1 :: FFI.ForeignObj -> Prelude.Int */
extern HsInt hs_getUBAEnd(void*);
#ifdef PROFILE
static SInfo pf_NHC_46BinArray_46hs_95getUBAEnd_35 = {"NHC.BinArray","NHC.BinArray.hs_getUBAEnd#","Prelude.Int"};
#endif
C_HEADER(FR_NHC_46BinArray_46hs_95getUBAEnd_35) {
  NodePtr nodeptr;
  HsInt result;
  void* arg1;
  nodeptr = C_GETARG1(1);
  IND_REMOVE(nodeptr);
  arg1 = (void*)derefForeignObj((ForeignObj*)GET_INT_VALUE(nodeptr));

  result = hs_getUBAEnd(arg1);

  nodeptr = nhc_mkInt(result);
  INIT_PROFINFO(nodeptr,&pf_NHC_46BinArray_46hs_95getUBAEnd_35);
  C_RETURN(nodeptr);
}
